@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 from django.shortcuts import render
+from django.conf import settings
 
 from explorer import app_settings
 
@@ -9,11 +10,12 @@ class ExplorerContextMixin:
     def gen_ctx(self):
         return {
             'can_view': app_settings.EXPLORER_PERMISSION_VIEW(
-                self.request.user
+                self.request
             ),
             'can_change': app_settings.EXPLORER_PERMISSION_CHANGE(
-                self.request.user
-            )
+                self.request
+            ),
+            'csrf_cookie_name': settings.CSRF_COOKIE_NAME,
         }
 
     def get_context_data(self, **kwargs):
